/*==============================================================*/
/* DBMS name:      PostgreSQL 8                                 */
/* Created on:     22/04/2008 10:54:54                          */
/*==============================================================*/

SET search_path = dbtabunificada, pg_catalog;

/*==============================================================*/
/* Table: RL_EXCECAO_COMPATIBILIDADE                            */
/*==============================================================*/
create table RL_EXCECAO_COMPATIBILIDADE (
   CO_PROCEDIMENTO_RESTRICAO VARCHAR(10)          not null,
   CO_PROCEDIMENTO_PRINCIPAL VARCHAR(10)          not null,
   CO_REGISTRO_PRINCIPAL CHAR(2)              not null,
   CO_PROCEDIMENTO_COMPATIVEL VARCHAR(10)          not null,
   CO_REGISTRO_COMPATIVEL CHAR(2)              not null,
   TP_COMPATIBILIDADE   CHAR(1)              not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_EXCECAO_COMPATIBILIDADE primary key (CO_PROCEDIMENTO_RESTRICAO, CO_PROCEDIMENTO_PRINCIPAL, CO_REGISTRO_PRINCIPAL, CO_PROCEDIMENTO_COMPATIVEL, CO_REGISTRO_COMPATIVEL, TP_COMPATIBILIDADE, DT_COMPETENCIA)
);

comment on column RL_EXCECAO_COMPATIBILIDADE.CO_PROCEDIMENTO_RESTRICAO is
'Cdigo do procedimento nega a Compatibilidade definida para o para abaixo.';

comment on column RL_EXCECAO_COMPATIBILIDADE.CO_PROCEDIMENTO_PRINCIPAL is
'Cdigo do procedimento que informa o procedimento principal da restrio.';

comment on column RL_EXCECAO_COMPATIBILIDADE.CO_REGISTRO_PRINCIPAL is
'Cdigo do instrumento de registro do procedimento base da compatibilidade.';

comment on column RL_EXCECAO_COMPATIBILIDADE.CO_PROCEDIMENTO_COMPATIVEL is
'Cdigo do procedimento que informa o procedimento secundrio da restrio.';

comment on column RL_EXCECAO_COMPATIBILIDADE.CO_REGISTRO_COMPATIVEL is
'Cdigo do instrumento de registro do procedimento a ser relacionado com o procedimento base para compatibilidade.';

comment on column RL_EXCECAO_COMPATIBILIDADE.TP_COMPATIBILIDADE is
'Cdigo que identifica as possveis compatibilidades entre procedimentos por forma de registro. Preenchimento: 
1 - Compatvel
2 - Incompatvel / Excludente
3 - Concomitante';

comment on column RL_EXCECAO_COMPATIBILIDADE.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_EXCECAO_COMPATIBILIDADE.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_EXCECAO_COMPATIBILIDADE.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_EXCECAO_COMPATIBILIDADE.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_CID                                   */
/*==============================================================*/
create table RL_PROCEDIMENTO_CID (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_CID               VARCHAR(4)           not null,
   ST_PRINCIPAL         CHAR(1)              null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_CID primary key (CO_PROCEDIMENTO, CO_CID, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_CID.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_CID.CO_CID is
'Cdigo que identifica o CID-10.';

comment on column RL_PROCEDIMENTO_CID.ST_PRINCIPAL is
'Define se este CID pode ser principal para a solicitao deste procedimento. Preenchimento: 
S - Sim
N - No';

comment on column RL_PROCEDIMENTO_CID.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_CID.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_CID.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_CID.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_COMPATIVEL                            */
/*==============================================================*/
create table RL_PROCEDIMENTO_COMPATIVEL (
   CO_PROCEDIMENTO_PRINCIPAL VARCHAR(10)          not null,
   CO_REGISTRO_PRINCIPAL VARCHAR(2)           not null,
   CO_PROCEDIMENTO_COMPATIVEL VARCHAR(10)          not null,
   CO_REGISTRO_COMPATIVEL VARCHAR(2)           not null,
   TP_COMPATIBILIDADE   VARCHAR(1)           not null,
   QT_PERMITIDA         NUMERIC(4)           null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_COMPATIVEL primary key (CO_PROCEDIMENTO_PRINCIPAL, CO_REGISTRO_PRINCIPAL, CO_PROCEDIMENTO_COMPATIVEL, CO_REGISTRO_COMPATIVEL, TP_COMPATIBILIDADE, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_COMPATIVEL.CO_PROCEDIMENTO_PRINCIPAL is
'Cdigo do procedimento base da compatibilidade.';

comment on column RL_PROCEDIMENTO_COMPATIVEL.CO_REGISTRO_PRINCIPAL is
'Cdigo do instrumento de registro do procedimento base da compatibilidade.';

comment on column RL_PROCEDIMENTO_COMPATIVEL.CO_PROCEDIMENTO_COMPATIVEL is
'Cdigo do procedimento a ser relacionado com o procedimento base para compatibilidade.';

comment on column RL_PROCEDIMENTO_COMPATIVEL.CO_REGISTRO_COMPATIVEL is
'Cdigo do instrumento de registro do procedimento a ser relacionado com o procedimento base para compatibilidade.';

comment on column RL_PROCEDIMENTO_COMPATIVEL.TP_COMPATIBILIDADE is
'Cdigo que identifica as possveis compatibilidades entre procedimentos por forma de registro. Preenchimento: 
1 - Compatvel
2 - Incompatvel / Excludente
3 - Concomitante';

comment on column RL_PROCEDIMENTO_COMPATIVEL.QT_PERMITIDA is
'Identifica a quantidade mxima possvel de realizao de um procedimentos.';

comment on column RL_PROCEDIMENTO_COMPATIVEL.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_COMPATIVEL.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_COMPATIVEL.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_COMPATIVEL.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_DETALHE                               */
/*==============================================================*/
create table RL_PROCEDIMENTO_DETALHE (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_DETALHE           VARCHAR(3)           not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_DETALHE primary key (CO_PROCEDIMENTO, CO_DETALHE, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_DETALHE.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_DETALHE.CO_DETALHE is
'Cdigo que identifica os atributos de detalhes de um procedimento.';

comment on column RL_PROCEDIMENTO_DETALHE.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_DETALHE.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_DETALHE.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_DETALHE.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_HABILITACAO                           */
/*==============================================================*/
create table RL_PROCEDIMENTO_HABILITACAO (
   CO_PROCEDIMENTO      VARCHAR(10)          null,
   CO_HABILITACAO       VARCHAR(4)           null,
   NU_GRUPO_HABILITACAO VARCHAR(4)           null,
   DT_COMPETENCIA       VARCHAR(6)           null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint UK_PROCHABIL_PROCHABICOMPGRHAB unique (CO_PROCEDIMENTO, CO_HABILITACAO, DT_COMPETENCIA, NU_GRUPO_HABILITACAO)
);

comment on column RL_PROCEDIMENTO_HABILITACAO.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_HABILITACAO.CO_HABILITACAO is
'Cdigo que identifica uma habilitao para o CNES.';

comment on column RL_PROCEDIMENTO_HABILITACAO.NU_GRUPO_HABILITACAO is
'Identifica um grupo de habilitaes requeridas para executar um dado procedimento.';

comment on column RL_PROCEDIMENTO_HABILITACAO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_HABILITACAO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_HABILITACAO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_HABILITACAO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_INCREMENTO                            */
/*==============================================================*/
create table RL_PROCEDIMENTO_INCREMENTO (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_HABILITACAO       VARCHAR(4)           not null,
   VL_PERCENTUAL_SH     NUMERIC(9,2)         null,
   VL_PERCENTUAL_SA     NUMERIC(9,2)         null,
   VL_PERCENTUAL_SP     NUMERIC(9,2)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_INCREMENTO primary key (CO_PROCEDIMENTO, CO_HABILITACAO, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_INCREMENTO.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_INCREMENTO.CO_HABILITACAO is
'Cdigo que identifica uma habilitao para o CNES.';

comment on column RL_PROCEDIMENTO_INCREMENTO.VL_PERCENTUAL_SH is
'Valor percentual de incremento para o Servio Hospitalar de um procedimento vinculado a uma dada Habilitao.';

comment on column RL_PROCEDIMENTO_INCREMENTO.VL_PERCENTUAL_SA is
'Valor percentual de incremento para o Servio Ambulatorial de um procedimento vinculado a uma dada Habilitao.';

comment on column RL_PROCEDIMENTO_INCREMENTO.VL_PERCENTUAL_SP is
'Valor percentual de incremento para o Servio Profissional de um procedimento vinculado a uma dada Habilitao.';

comment on column RL_PROCEDIMENTO_INCREMENTO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_INCREMENTO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_INCREMENTO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_INCREMENTO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_LEITO                                 */
/*==============================================================*/
create table RL_PROCEDIMENTO_LEITO (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_TIPO_LEITO        VARCHAR(2)           not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_LEITO primary key (CO_PROCEDIMENTO, CO_TIPO_LEITO, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_LEITO.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_LEITO.CO_TIPO_LEITO is
'Cdigo da classificao de leito.';

comment on column RL_PROCEDIMENTO_LEITO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_LEITO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_LEITO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_LEITO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_MODALIDADE                            */
/*==============================================================*/
create table RL_PROCEDIMENTO_MODALIDADE (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_MODALIDADE        VARCHAR(2)           not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_MODALIDADE primary key (CO_PROCEDIMENTO, CO_MODALIDADE, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_MODALIDADE.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_MODALIDADE.CO_MODALIDADE is
'Cdigo que identifica as modalidades de atendimentos.';

comment on column RL_PROCEDIMENTO_MODALIDADE.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_MODALIDADE.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_MODALIDADE.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_MODALIDADE.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_OCUPACAO                              */
/*==============================================================*/
create table RL_PROCEDIMENTO_OCUPACAO (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_OCUPACAO          CHAR(6)              not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_OCUPACAO primary key (CO_PROCEDIMENTO, CO_OCUPACAO, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_OCUPACAO.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_OCUPACAO.CO_OCUPACAO is
'Cdigo que identifica a classificao das ocupaes definidas pela CBO-2002.';

comment on column RL_PROCEDIMENTO_OCUPACAO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_OCUPACAO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_OCUPACAO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_OCUPACAO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_ORIGEM                                */
/*==============================================================*/
create table RL_PROCEDIMENTO_ORIGEM (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_PROCEDIMENTO_ORIGEM VARCHAR(10)          not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_ORIGEM primary key (CO_PROCEDIMENTO, CO_PROCEDIMENTO_ORIGEM, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_ORIGEM.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_ORIGEM.CO_PROCEDIMENTO_ORIGEM is
'Cdigo que identifica o procedimento que deu origem ao novo procedimento da tabela unificada.';

comment on column RL_PROCEDIMENTO_ORIGEM.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_ORIGEM.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_ORIGEM.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_ORIGEM.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_REGISTRO                              */
/*==============================================================*/
create table RL_PROCEDIMENTO_REGISTRO (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_REGISTRO          VARCHAR(2)           not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_REGISTRO primary key (CO_PROCEDIMENTO, CO_REGISTRO, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_REGISTRO.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_REGISTRO.CO_REGISTRO is
'Cdigo do instrumento de registro do procedimento.';

comment on column RL_PROCEDIMENTO_REGISTRO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_REGISTRO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_REGISTRO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_REGISTRO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_SERVICO                               */
/*==============================================================*/
create table RL_PROCEDIMENTO_SERVICO (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_SERVICO           VARCHAR(3)           not null,
   CO_CLASSIFICACAO     VARCHAR(3)           not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_SERVICO primary key (CO_PROCEDIMENTO, CO_SERVICO, CO_CLASSIFICACAO, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_SERVICO.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_SERVICO.CO_SERVICO is
'Cdigo que identifica os servios.';

comment on column RL_PROCEDIMENTO_SERVICO.CO_CLASSIFICACAO is
'Cdigo que identifica a classificao de um servio.';

comment on column RL_PROCEDIMENTO_SERVICO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_SERVICO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_SERVICO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_SERVICO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: RL_PROCEDIMENTO_SIA_SIH                               */
/*==============================================================*/
create table RL_PROCEDIMENTO_SIA_SIH (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   CO_PROCEDIMENTO_SIA_SIH VARCHAR(10)          not null,
   TP_PROCEDIMENTO      VARCHAR(1)           not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO_SIA_SIH primary key (CO_PROCEDIMENTO, CO_PROCEDIMENTO_SIA_SIH, TP_PROCEDIMENTO, DT_COMPETENCIA)
);

comment on column RL_PROCEDIMENTO_SIA_SIH.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column RL_PROCEDIMENTO_SIA_SIH.CO_PROCEDIMENTO_SIA_SIH is
'Cdigo que identifica o procedimento do SAI e SIH que deu origem ao novo procedimento da tabela unificada.';

comment on column RL_PROCEDIMENTO_SIA_SIH.TP_PROCEDIMENTO is
'Define qual era o tipo do procedimento SAI e/ou SIH de origem do novo procedimento. Preenchimento: 
A - Ambulatorial
H - Hospitalar';

comment on column RL_PROCEDIMENTO_SIA_SIH.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column RL_PROCEDIMENTO_SIA_SIH.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column RL_PROCEDIMENTO_SIA_SIH.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column RL_PROCEDIMENTO_SIA_SIH.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_CID                                                */
/*==============================================================*/
create table TB_CID (
   CO_CID               VARCHAR(4)           not null,
   NO_CID               VARCHAR(100)         null,
   TP_AGRAVO            CHAR(1)              null,
   TP_SEXO              CHAR(1)              null,
   ST_REGISTRO_ATIVO    VARCHAR(1)           null,
   DT_INATIVACAO        DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_CID primary key (CO_CID)
);

comment on column TB_CID.CO_CID is
'Cdigo que identifica o CID-10.';

comment on column TB_CID.NO_CID is
'Nome da doena.';

comment on column TB_CID.TP_AGRAVO is
'Define o tipo de agravo que deve ser notificado. Preenchimento: 
0 - Sem Agravo
1 - Agravo de notificao
2 - Agravo de bloqueio';

comment on column TB_CID.TP_SEXO is
'Define a abrangncia de sexo para a aplicao do procedimento. Preenchimento: 
M - Masculino
F - Feminino
I - Indiferente/Ambos';

comment on column TB_CID.ST_REGISTRO_ATIVO is
'Indica se o registro est ativo - S, no est ativo - N. O registro ser inativado quando ele no aparecer em um arquivo de atualizao.';

comment on column TB_CID.DT_INATIVACAO is
'Data em que o registro foi inativado.';

comment on column TB_CID.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_CONTROLE_ARQUIVO                                   */
/*==============================================================*/
create table TB_CONTROLE_ARQUIVO (
   DT_MANUTENCAO        DATE                 null,
   DS_MANUTENCAO_LEIAME VARCHAR(4000)        null,
   DS_URL               VARCHAR(200)         null,
   DT_MANUTENCAO_SITE   DATE                 null,
   DS_COMANDO_MANUT_ESTRUTURA VARCHAR(4000)        null,
   DS_OBSERVACAO        VARCHAR(4000)        null
);

comment on column TB_CONTROLE_ARQUIVO.DT_MANUTENCAO is
'Data da manuteno nas tabelas do schema dbtabunificada.';

comment on column TB_CONTROLE_ARQUIVO.DS_MANUTENCAO_LEIAME is
'Pedao do texto Leia-me.txt onde fala sobre a ltima atualizao do arquivo.';

comment on column TB_CONTROLE_ARQUIVO.DS_URL is
'URL na pgina do DATASUS onde foi feito o anuncio da atualizao. Quando esta atualizao no for
anunciada no site, este campo ser preenchido com o dado "via email".';

comment on column TB_CONTROLE_ARQUIVO.DT_MANUTENCAO_SITE is
'Data da manuteno que est anunciada no site.';

comment on column TB_CONTROLE_ARQUIVO.DS_COMANDO_MANUT_ESTRUTURA is
'Comando DDL que foi rodado para alterao de estrutura, caso acontea.';

comment on column TB_CONTROLE_ARQUIVO.DS_OBSERVACAO is
'Observaes a respeito do arquivo que chegou.';

/*==============================================================*/
/* Table: TB_DETALHE                                            */
/*==============================================================*/
create table TB_DETALHE (
   CO_DETALHE           VARCHAR(3)           not null,
   NO_DETALHE           VARCHAR(100)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_DETALHE primary key (CO_DETALHE, DT_COMPETENCIA)
);

comment on column TB_DETALHE.CO_DETALHE is
'Cdigo que identifica os atributos de detalhes de um procedimento.';

comment on column TB_DETALHE.NO_DETALHE is
'Nome que descreve os atributos de detalhes de um procedimento.';

comment on column TB_DETALHE.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_DETALHE.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_DETALHE.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_DETALHE.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_FINANCIAMENTO                                      */
/*==============================================================*/
create table TB_FINANCIAMENTO (
   CO_FINANCIAMENTO     VARCHAR(2)           not null,
   NO_FINANCIAMENTO     VARCHAR(100)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_FINANCIAMENTO primary key (CO_FINANCIAMENTO, DT_COMPETENCIA)
);

comment on column TB_FINANCIAMENTO.CO_FINANCIAMENTO is
'Cdigo que identifica os tipos de financiamento de um procedimento.';

comment on column TB_FINANCIAMENTO.NO_FINANCIAMENTO is
'Nome que descreve os tipos de financiamento de um procedimento. Preenchimento: 
01 - Ateno Bsica (PAB)
02 - Mdia e Alta complecidade (MAC)
03 - Fundo de Aes Estratgicas e Compensaes (FAEC)
04 - Viligncia em Sade
05 - Assistncia Farmacutica
06 - Assistncia Farmacutica e MAC
07 - Incentivo MAC';

comment on column TB_FINANCIAMENTO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_FINANCIAMENTO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_FINANCIAMENTO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_FINANCIAMENTO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_FORMA_ORGANIZACAO                                  */
/*==============================================================*/
create table TB_FORMA_ORGANIZACAO (
   CO_GRUPO             VARCHAR(2)           not null,
   CO_SUB_GRUPO         VARCHAR(2)           not null,
   CO_FORMA_ORGANIZACAO VARCHAR(2)           not null,
   NO_FORMA_ORGANIZACAO VARCHAR(100)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_FORMA_ORGANIZACAO primary key (CO_GRUPO, CO_SUB_GRUPO, CO_FORMA_ORGANIZACAO, DT_COMPETENCIA)
);

comment on column TB_FORMA_ORGANIZACAO.CO_GRUPO is
'Cdigo do grupo dos procedimentos.';

comment on column TB_FORMA_ORGANIZACAO.CO_SUB_GRUPO is
'Cdigo do sub-grupo dos procedimentos.';

comment on column TB_FORMA_ORGANIZACAO.CO_FORMA_ORGANIZACAO is
'Cdigo da forma de organizao dos procedimentos.';

comment on column TB_FORMA_ORGANIZACAO.NO_FORMA_ORGANIZACAO is
'Nome da forma de organizao dos procedimentos.';

comment on column TB_FORMA_ORGANIZACAO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM.';

comment on column TB_FORMA_ORGANIZACAO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_FORMA_ORGANIZACAO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_FORMA_ORGANIZACAO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_GRUPO                                              */
/*==============================================================*/
create table TB_GRUPO (
   CO_GRUPO             VARCHAR(2)           not null,
   NO_GRUPO             VARCHAR(100)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_GRUPO primary key (CO_GRUPO, DT_COMPETENCIA)
);

comment on column TB_GRUPO.CO_GRUPO is
'Cdigo do grupo dos procedimentos.';

comment on column TB_GRUPO.NO_GRUPO is
'Nome do grupo dos procedimentos.';

comment on column TB_GRUPO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM.';

comment on column TB_GRUPO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_GRUPO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_GRUPO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_HABILITACAO                                        */
/*==============================================================*/
create table TB_HABILITACAO (
   CO_HABILITACAO       VARCHAR(4)           not null,
   NO_HABILITACAO       VARCHAR(150)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_HABILITACAO primary key (CO_HABILITACAO, DT_COMPETENCIA)
);

comment on column TB_HABILITACAO.CO_HABILITACAO is
'Cdigo que identifica uma habilitao para o CNES.';

comment on column TB_HABILITACAO.NO_HABILITACAO is
'Nome de uma habilitao.';

comment on column TB_HABILITACAO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_HABILITACAO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_HABILITACAO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_HABILITACAO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_MODALIDADE                                         */
/*==============================================================*/
create table TB_MODALIDADE (
   CO_MODALIDADE        VARCHAR(2)           not null,
   NO_MODALIDADE        VARCHAR(100)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_MODALIDADE primary key (CO_MODALIDADE, DT_COMPETENCIA)
);

comment on column TB_MODALIDADE.CO_MODALIDADE is
'Cdigo que identifica as modalidades de atendimentos.';

comment on column TB_MODALIDADE.NO_MODALIDADE is
'Nome que descreve as modalidades de atendimentos possveis para um procedimento. Preenchimento: 
Ambulatorial
Hospitalar
Hospital-Dia
Assistncia Domiciliar
Internao Domiciliar';

comment on column TB_MODALIDADE.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_MODALIDADE.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_MODALIDADE.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_MODALIDADE.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_OCUPACAO                                           */
/*==============================================================*/
create table TB_OCUPACAO (
   CO_OCUPACAO          CHAR(6)              not null,
   NO_OCUPACAO          VARCHAR(150)         null,
   ST_REGISTRO_ATIVO    VARCHAR(1)           null,
   DT_INATIVACAO        DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_OCUPACAO primary key (CO_OCUPACAO)
);

comment on column TB_OCUPACAO.CO_OCUPACAO is
'Cdigo que identifica a classificao das ocupaes definidas pela CBO-2002.';

comment on column TB_OCUPACAO.NO_OCUPACAO is
'Nome das ocupaes definidas pela CBO-2002.';

comment on column TB_OCUPACAO.ST_REGISTRO_ATIVO is
'Indica se o registro est ativo - S, no est ativo - N. O registro ser inativado quando ele no aparecer em um arquivo de atualizao.';

comment on column TB_OCUPACAO.DT_INATIVACAO is
'Data em que o registro foi inativado.';

comment on column TB_OCUPACAO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_PROCEDIMENTO                                       */
/*==============================================================*/
create table TB_PROCEDIMENTO (
   CO_PROCEDIMENTO      VARCHAR(10)          not null,
   NO_PROCEDIMENTO      VARCHAR(250)         null,
   TP_COMPLEXIDADE      VARCHAR(1)           null,
   TP_SEXO              VARCHAR(1)           null,
   QT_MAXIMA_EXECUCAO   NUMERIC(4)           null,
   QT_DIAS_PERMANENCIA  NUMERIC(4)           null,
   QT_PONTOS            NUMERIC(4)           null,
   VL_IDADE_MINIMA      NUMERIC(4)           null,
   VL_IDADE_MAXIMA      NUMERIC(4)           null,
   VL_SH                NUMERIC(12,2)        null,
   VL_SA                NUMERIC(12,2)        null,
   VL_SP                NUMERIC(12,2)        null,
   CO_FINANCIAMENTO     VARCHAR(2)           null,
   CO_RUBRICA           VARCHAR(6)           null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_PROCEDIMENTO primary key (CO_PROCEDIMENTO, DT_COMPETENCIA)
);

comment on column TB_PROCEDIMENTO.CO_PROCEDIMENTO is
'Cdigo do procedimento.';

comment on column TB_PROCEDIMENTO.NO_PROCEDIMENTO is
'Nome descritivo do procedimento.';

comment on column TB_PROCEDIMENTO.TP_COMPLEXIDADE is
'Define a complexidade do procedimento. Preenchimento:
0 - No se aplica
1 - Ateno Bsica Complexidade
2 - Mdia Complexidade
3 - Alta Complexidade';

comment on column TB_PROCEDIMENTO.TP_SEXO is
'Define a abrangncia de sexo para a aplicao do procedimento. Preenchimento:
M - Masculino
F - Feminino
I - Indiferente/Ambos
N - No se aplica';

comment on column TB_PROCEDIMENTO.QT_MAXIMA_EXECUCAO is
'Nmero mximo de execues permitidas. Preenchimento: 9999 se no se aplica.';

comment on column TB_PROCEDIMENTO.QT_DIAS_PERMANENCIA is
'Nmero mximo de dias de internaes possveis. Preenchimento: 9999 se no se aplica.';

comment on column TB_PROCEDIMENTO.QT_PONTOS is
'Quantidade de pontos para o procedimento. Preenchimento: 9999 se no se aplica.';

comment on column TB_PROCEDIMENTO.VL_IDADE_MINIMA is
'Idade mnima para o uso um procedimento em meses. Preenchimento: De 0000 a 1331 meses. 9999 se no se aplica.';

comment on column TB_PROCEDIMENTO.VL_IDADE_MAXIMA is
'Idade mxima para o uso um procedimento em meses. Preenchimento: De 0000 a 1331 meses. 9999 se no se aplica.';

comment on column TB_PROCEDIMENTO.VL_SH is
'Valor pago para o servio hospitalar deste procedimento.';

comment on column TB_PROCEDIMENTO.VL_SA is
'Valor pago para o servio ambulatorial deste procedimento.';

comment on column TB_PROCEDIMENTO.VL_SP is
'Valor pago para o servio profissional deste procedimento.';

comment on column TB_PROCEDIMENTO.CO_FINANCIAMENTO is
'Cdigo que identifica os tipos de financiamento de um procedimento.';

comment on column TB_PROCEDIMENTO.CO_RUBRICA is
'Cdigo que identifica as rubricas.';

comment on column TB_PROCEDIMENTO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_PROCEDIMENTO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_PROCEDIMENTO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_PROCEDIMENTO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_REGISTRO                                           */
/*==============================================================*/
create table TB_REGISTRO (
   CO_REGISTRO          VARCHAR(2)           not null,
   NO_REGISTRO          VARCHAR(50)          null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_REGISTRO primary key (CO_REGISTRO, DT_COMPETENCIA)
);

comment on column TB_REGISTRO.CO_REGISTRO is
'Cdigo do instrumento de registro do procedimento.';

comment on column TB_REGISTRO.NO_REGISTRO is
'Nome do instrumento de registro do procedimento. Preenchimento: 
BPA (CONSOLIDADO)
BPA (INDIVIDUALIZADO)
APAC (PROCEDIMENTO PRINCIPAL) 
APAC (PROCEDIMENTO SECUNDARIO) 
AIH (PROCEDIMENTO PRINCIPAL) 
AIH (PROCEDIMENTO SECUNDARIO) 
AIH (ESPECIAL)';

comment on column TB_REGISTRO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_REGISTRO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_REGISTRO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_REGISTRO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_RUBRICA                                            */
/*==============================================================*/
create table TB_RUBRICA (
   CO_RUBRICA           VARCHAR(6)           not null,
   NO_RUBRICA           VARCHAR(100)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_RUBRICA primary key (CO_RUBRICA, DT_COMPETENCIA)
);

comment on column TB_RUBRICA.CO_RUBRICA is
'Cdigo que identifica as rubricas. As duas primeiras posies identifica o cdigo de financiamento.';

comment on column TB_RUBRICA.NO_RUBRICA is
'Nome das rubricas.';

comment on column TB_RUBRICA.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_RUBRICA.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_RUBRICA.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_RUBRICA.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_SERVICO                                            */
/*==============================================================*/
create table TB_SERVICO (
   CO_SERVICO           VARCHAR(3)           not null,
   NO_SERVICO           VARCHAR(120)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_SERVICO primary key (CO_SERVICO, DT_COMPETENCIA)
);

comment on column TB_SERVICO.CO_SERVICO is
'Cdigo que identifica os servios.';

comment on column TB_SERVICO.NO_SERVICO is
'Nome que descreve os servios.';

comment on column TB_SERVICO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_SERVICO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_SERVICO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_SERVICO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_SERVICO_CLASSIFICACAO                              */
/*==============================================================*/
create table TB_SERVICO_CLASSIFICACAO (
   CO_SERVICO           VARCHAR(3)           not null,
   CO_CLASSIFICACAO     VARCHAR(3)           not null,
   NO_CLASSIFICACAO     VARCHAR(150)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_SERVICO_CLASSIFICACAO primary key (CO_SERVICO, CO_CLASSIFICACAO, DT_COMPETENCIA)
);

comment on column TB_SERVICO_CLASSIFICACAO.CO_SERVICO is
'Cdigo que identifica os servios.';

comment on column TB_SERVICO_CLASSIFICACAO.CO_CLASSIFICACAO is
'Cdigo que identifica a classificao de um servio.';

comment on column TB_SERVICO_CLASSIFICACAO.NO_CLASSIFICACAO is
'Nome que descreve a classificao de um servio.';

comment on column TB_SERVICO_CLASSIFICACAO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_SERVICO_CLASSIFICACAO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_SERVICO_CLASSIFICACAO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_SERVICO_CLASSIFICACAO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_SIA_SIH                                            */
/*==============================================================*/
create table TB_SIA_SIH (
   CO_PROCEDIMENTO_SIA_SIH VARCHAR(10)          not null,
   NO_PROCEDIMENTO_SIA_SIH VARCHAR(100)         null,
   TP_PROCEDIMENTO      VARCHAR(1)           not null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_SIA_SIH primary key (CO_PROCEDIMENTO_SIA_SIH, TP_PROCEDIMENTO, DT_COMPETENCIA)
);

comment on column TB_SIA_SIH.CO_PROCEDIMENTO_SIA_SIH is
'Cdigo que identifica os procedimento do SAI e SIH na data de vigncia da nova tabela.';

comment on column TB_SIA_SIH.NO_PROCEDIMENTO_SIA_SIH is
'Nome dos procedimento do SAI e SIH na data de vigncia da nova tabela.';

comment on column TB_SIA_SIH.TP_PROCEDIMENTO is
'Define qual era o tipo do procedimento SAI e/ou SIH de origem do novo procedimento. Preenchimento: 
A - Ambulatorial
H - Hospitalar';

comment on column TB_SIA_SIH.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_SIA_SIH.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_SIA_SIH.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_SIA_SIH.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_SUB_GRUPO                                          */
/*==============================================================*/
create table TB_SUB_GRUPO (
   CO_GRUPO             VARCHAR(2)           not null,
   CO_SUB_GRUPO         VARCHAR(2)           not null,
   NO_SUB_GRUPO         VARCHAR(100)         null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_SUB_GRUPO primary key (CO_GRUPO, CO_SUB_GRUPO, DT_COMPETENCIA)
);

comment on column TB_SUB_GRUPO.CO_GRUPO is
'Cdigo do grupo dos procedimentos.';

comment on column TB_SUB_GRUPO.CO_SUB_GRUPO is
'Cdigo do sub-grupo dos procedimentos.';

comment on column TB_SUB_GRUPO.NO_SUB_GRUPO is
'Nome do sub-grupo dos procedimentos.';

comment on column TB_SUB_GRUPO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM.';

comment on column TB_SUB_GRUPO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_SUB_GRUPO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_SUB_GRUPO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

/*==============================================================*/
/* Table: TB_TIPO_LEITO                                         */
/*==============================================================*/
create table TB_TIPO_LEITO (
   CO_TIPO_LEITO        VARCHAR(2)           not null,
   NO_TIPO_LEITO        VARCHAR(60)          null,
   DT_COMPETENCIA       VARCHAR(6)           not null,
   ST_VALIDADE          VARCHAR(1)           null,
   DT_CANCELAMENTO      DATE                 null,
   DT_ULTIMA_ATUALIZACAO DATE                 null,
   constraint PK_TIPO_LEITO primary key (CO_TIPO_LEITO, DT_COMPETENCIA)
);

comment on column TB_TIPO_LEITO.CO_TIPO_LEITO is
'Cdigo da classificao de leito';

comment on column TB_TIPO_LEITO.NO_TIPO_LEITO is
'Nome da classificao de leito. Preenchimento: 
01 - Cirrgico                                  
02 - Obsttricos                                
03 - Clnico                                    
04 - Crnicos                                   
05 - Psiquiatria                                
06 - Pneum';

comment on column TB_TIPO_LEITO.DT_COMPETENCIA is
'Data que informa a competncia de validade deste registro. Preenchimento: YYYYMM';

comment on column TB_TIPO_LEITO.ST_VALIDADE is
'Indica se o registro est vlido - S, no est vlido - N e est cancelado - C. O registro ser vlido quando a data da competncia  a mais atual. O registro no ser vlido quando a data da competncia no  a mais atual. O registro ser cancelado quando ele no aparecer em um arquivo de atualizao para a mesma competncia.';

comment on column TB_TIPO_LEITO.DT_CANCELAMENTO is
'Data em que o registro foi cancelado.';

comment on column TB_TIPO_LEITO.DT_ULTIMA_ATUALIZACAO is
'Data da ltima atualizacao do registro (incluso ou alterao do registro).';

